/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console;

import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;

import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.core.IconLibrary;
import net.sf.dc.core.actions.AboutAction;
import net.sf.dc.core.actions.CreateNewAction;
import net.sf.dc.core.actions.DeleteAction;
import net.sf.dc.core.actions.ExpertUserAction;
import net.sf.dc.core.actions.HelpAction;
import net.sf.dc.core.actions.InternetUpdateAction;
import net.sf.dc.core.actions.LogAction;
import net.sf.dc.core.actions.OpenAction;
import net.sf.dc.core.actions.OpenAudioCDModuleAction;
import net.sf.dc.core.actions.OpenMovieModuleAction;
import net.sf.dc.core.actions.OpenMusicModuleAction;
import net.sf.dc.core.actions.OpenSoftwareModuleAction;
import net.sf.dc.core.actions.QuitApplicationAction;
import net.sf.dc.core.actions.SettingsAction;
import net.sf.dc.core.actions.ToggleModuleListAction;
import net.sf.dc.core.modules.DCModule;
import net.sf.dc.core.modules.DCModules;
import net.sf.dc.resources.DCLabels;
import net.sf.ext.util.Resources;

/**
 * Creates a menu bar for a specific module (dynamic). 
 * All actions for this menubar 
 * can be found in the net.sf.dc.core.actions package
 *
 * @author Robert-Jan van der Waals
 * @since 1.4
 * @version 1.50
 */
public class DCMenuBar extends JMenuBar {

	private static final long serialVersionUID = 1L;
	
	public static final int _SEARCHPANEL = 0;
    public static final int _INSERTPANEL = 1;
    public static final int _NOTEPANEL = 2;
    
    private final DCModule module;

    /**
     * Initializes this menubar for the specified module
     * @param module
     */
    public DCMenuBar(DCModule module) {
        this.module = module;
    	build();
    }
    
    public void setPanel(int index) {
        switch (index) {
            case _SEARCHPANEL:
                break;
            case _INSERTPANEL:
                break;
            case _NOTEPANEL:
                break;
        }
    }
    
    /**
     * Builds this menubar
     */
    private void build() {
        String dcoName = module.getObjectName();
        
        JMenu menuTools = module.getToolsMenu();
        if (menuTools == null) {
        	menuTools = ComponentFactory.getMenu(
                    Resources.getText(DCLabels.lblTools));
        }
        
        JMenu menuSettings = ComponentFactory.getMenu(
                Resources.getText(DCLabels.lblSettings));
        JMenu menuFile = ComponentFactory.getMenu(
                Resources.getText(DCLabels.lblFile));
        JMenu menuInformation = ComponentFactory.getMenu(
                Resources.getText(DCLabels.lblInformation));

        // information menu
        JMenuItem menuItemAbout = ComponentFactory.getMenuItem(
                IconLibrary._icoMenuAbout16,
                Resources.getText(DCLabels.lblAbout));
        JMenuItem menuItemHelp = ComponentFactory.getMenuItem(
                IconLibrary._icoMenuHelp16, 
                Resources.getText(DCLabels.lblHelp));

        menuItemHelp.addActionListener(new HelpAction());
        menuItemAbout.addActionListener(new AboutAction());

        menuInformation.add(menuItemAbout);
        menuInformation.add(menuItemHelp);
        
        // file menu
        JMenuItem menuItemLog = ComponentFactory.getMenuItem(     
                IconLibrary._icoMenuLog16, 
                Resources.getText(DCLabels.lblLogEvent));
        JMenuItem menuItemNew = ComponentFactory.getMenuItem(     
                IconLibrary._icoMenuNew16, 
                Resources.getText(DCLabels.lblNewItem, dcoName));
        JMenuItem menuItemOpen = ComponentFactory.getMenuItem(    
                IconLibrary._icoMenuOpen16,
				Resources.getText(DCLabels.lblOpenItem, dcoName));
        JMenuItem menuItemDelete = ComponentFactory.getMenuItem(  
                IconLibrary._icoMenuRemove16, 
                Resources.getText(DCLabels.lblDeleteItem, dcoName));
        JMenuItem menuItemQuit = ComponentFactory.getMenuItem(
                IconLibrary._icoMenuExit16,
				Resources.getText(DCLabels.lblQuit));

        menuItemNew.addActionListener(new CreateNewAction());
        menuItemOpen.addActionListener(new OpenAction());
        menuItemQuit.addActionListener(new QuitApplicationAction());
        menuItemDelete.addActionListener(new DeleteAction());
        menuItemLog.addActionListener(new LogAction());
        
        menuFile.add(menuItemNew);
        menuFile.add(menuItemOpen);
        menuFile.add(menuItemDelete);
        menuFile.addSeparator();
        menuFile.add(menuItemLog);
        menuFile.add(menuItemQuit);

        // module submenu
        JMenu subMenuModule = ComponentFactory.getMenu(
                Resources.getText(DCLabels.lblActiveModule));
        JMenuItem menuSoftware = ComponentFactory.getMenuItem(
                Resources.getText(DCLabels.lblModuleSoftware));
        JMenuItem menuMusicFile = ComponentFactory.getMenuItem(
                Resources.getText(DCLabels.lblModuleMusicFile));
        JMenuItem menuMovie = ComponentFactory.getMenuItem(
                Resources.getText(DCLabels.lblModuleMovie));
        JMenuItem menuAudioCD = ComponentFactory.getMenuItem(
                Resources.getText(DCLabels.lblModuleAudioCD));
        
        menuSoftware.addActionListener(new OpenSoftwareModuleAction());
        menuMusicFile.addActionListener(new OpenMusicModuleAction());
        menuMovie.addActionListener(new OpenMovieModuleAction());
        menuAudioCD.addActionListener(new OpenAudioCDModuleAction());
        
        subMenuModule.add(menuSoftware);
        subMenuModule.add(menuMovie);
        subMenuModule.add(menuMusicFile);
        subMenuModule.add(menuAudioCD);
        
        // settings menu
        JMenuItem menuItemSettings = ComponentFactory.getMenuItem(
                IconLibrary._icoMenuOption16, 
                Resources.getText(DCLabels.lblSettings));
        JMenuItem menuItemShowModList = ComponentFactory.getMenuItem(
                Resources.getText(DCLabels.lblToggleModuleList));
        
        menuItemShowModList.addActionListener(new ToggleModuleListAction());
        menuItemSettings.addActionListener(new SettingsAction());
        
        menuSettings.add(menuItemSettings);
        menuSettings.add(menuItemShowModList);
        menuSettings.add(subMenuModule);

        // tools menu
        if (    module.isAmazonUpdateAllowed() || 
                module.isImdbUpdateAllowed() || 
                module.getIndex() == DCModules._AUDIOCD) {

            JMenuItem menuItemOnlineSearch = ComponentFactory.getMenuItem(
                    IconLibrary._icoMenuInternetSearch16, 
                    Resources.getText(DCLabels.lblOnlineSearch));
            menuItemOnlineSearch.addActionListener(new InternetUpdateAction());
            menuTools.add(menuItemOnlineSearch);
        }

        JMenuItem menuExpertUser = ComponentFactory.getMenuItem(
                IconLibrary._icoMenuOption16,
                Resources.getText(DCLabels.lblExpertUser));
        menuExpertUser.addActionListener(new ExpertUserAction());
        menuTools.add(menuExpertUser);
        
        this.add(menuFile);
        this.add(menuSettings);

        this.add(menuTools);
        this.add(menuInformation);
    }
}
