/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.audiocd;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.Iterator;

import javax.swing.JButton;
import javax.swing.JComponent;

import net.sf.dc.console.TableSearchPanel;
import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.console.dialogs.MessageBox;
import net.sf.dc.core.IconLibrary;
import net.sf.dc.core.modules.DCModules;
import net.sf.dc.core.objects.DCObject;
import net.sf.dc.exceptions.ValidationException;
import net.sf.dc.resources.DCLabels;
import net.sf.dc.resources.DCMessages;
import net.sf.dc.wf.requests.RemoveNewTrackRequest;
import net.sf.ext.util.Resources;

/**
 * The insert Audio Track panel. This panel is different from the default panels
 * as this is a child panel of the Audio CD Panel. It also allows inserts of new
 * audio tracks
 * @see net.sf.dc.console.audiocd.SearchAudioCDPanel
 * 
 * @author Robert-Jan van der Waals
 * @since 1.4
 * @version 1.50
 */
public class SearchAudioTrackPanel extends TableSearchPanel {

    private ArrayList alNewTracks = new ArrayList();
    
    public SearchAudioTrackPanel() {
        super(DCModules.getModule(DCModules._AUDIOTRACK),
              Resources.getText(DCLabels.lblAudioTrack), 
              IconLibrary._icoExisting);
    }
    
    public JComponent[] getExtraComponents() {
        JButton buttonAddTrack = ComponentFactory.getButton(Resources.getText(DCLabels.lblAddTrack));
        buttonAddTrack.addActionListener(new AddTrackAcionListener());
        return new JComponent[] {buttonAddTrack};
    }
    
    /**
     * Saves both the changes values as well as newly added tracks
     */
    public void saveChangedValues(boolean threaded) {
        saveNewValues(); 
    }
    
    /**
     * Indicates whether there are unsaved changes
     */
    public boolean changesSaved() {
        boolean saved = (table.noChanges()) && (alNewTracks.size() == 0); 
        return saved;
    }    
    
    /**
     * Clears the table and its cache
     */
    public void clearTable() {
    	super.clearTable();
        alNewTracks.clear();
    }
    
    public void removeNewChild(String sID) {
    	alNewTracks.remove(sID);
    }
    
    /**
     * Saves newly added track objects
     */
    private void saveNewValues() {
        for (Iterator iter = alNewTracks.iterator(); iter.hasNext(); ) {
        	String ID = iter.next().toString();
            int row = table.getRowNumberWithID(ID);

            if (row > -1) {
                DCObject o = table.getDCObject(row);
                o.setValue(o.getParentReferenceFieldIndex(), getParentID());
                o.addRequest(new RemoveNewTrackRequest(getModule().getIndex(), ID));
                o.setBatch(true);
                o.setSilence(true);
                o.setEndOfBatch(false);
                o.setRow(row);
                
                try {
                    o.saveNew();
                } catch (ValidationException vExp) {
                    new MessageBox(vExp.getMessage(), MessageBox._WARNING);
                    return;
                }
            }
        }
        setStatus(Resources.getText(DCMessages.msgSaveHasBeenExecuted));        
    }  
    
    private class AddTrackAcionListener implements ActionListener {
        public void actionPerformed(ActionEvent arg0) {
            if (getParentID() != null && !getParentID().equals("")) {
            	DCObject dco = getModule().getDCObject();
            	table.addObject(dco);
                alNewTracks.add(dco.getID());
            } else {
            	new MessageBox("Not allowed, add / select an album first !", 
                               MessageBox._ERROR);
            }
        }
    }  
}
