/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.components;

import java.awt.Color;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.beans.PropertyChangeListener;

import javax.swing.Action;
import javax.swing.ActionMap;
import javax.swing.ComponentInputMap;
import javax.swing.InputMap;
import javax.swing.JCheckBox;
import javax.swing.JComponent;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JLayeredPane;
import javax.swing.JPanel;
import javax.swing.JRootPane;
import javax.swing.JTabbedPane;
import javax.swing.KeyStroke;

import net.sf.dc.core.Repository;
import net.sf.dc.helpsystem.JavaHelp;
import net.sf.ext.jflexsett.settings.Settings;

/**
 * Godfather for all dialogs
 *
 * @author Robert Jan van der Waals
 * @since 1.4
 * @version 1.6
 */
public class DCDialog extends JDialog {

    private String helpIndex = null;
    
    /**
     * Initializes the dialog and set a frame as its parent
     * @param parent
     */
    public DCDialog(JFrame parent) {
        super(parent);
        addHelpListener();
    }
    
    public DCDialog() {
        addHelpListener();
    }
    
    /**
     * Set the help index for this dialog
     * @param helpIndex
     */
    public void setHelpIndex(String helpIndex) {
    	this.helpIndex = helpIndex;
    }

    public void setVisible(boolean visible) {
        super.setVisible(visible);
        setBackground(Settings.getValueAsColor(Repository.settings.stColor));
    }    
    
    /**
     * Adds a listener for the F1 key
     */
    private void addHelpListener() {
        JRootPane rootPane = getRootPane();
        ActionMap parentActionMap = rootPane.getActionMap();
        ActionMap am = new ActionMap();
        am.setParent(parentActionMap);
        am.put("helpAction", new HelpAction());
        rootPane.setActionMap(am);
         
         
        InputMap parentInputMap = rootPane.getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
        ComponentInputMap im = new ComponentInputMap(getRootPane());
        try {
            im.setParent(parentInputMap);
        } catch (Exception ignore) {}
        im.put(KeyStroke.getKeyStroke("F1"), "helpAction");   // Bind the F1 key  to the MyAction action
        rootPane.setInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT, im);           
    }
    
    public void setBackground(Color color) {
        super.setBackground(color);
        Component[] components = getComponents();
        for (int i = 0; i < components.length; i++) {
            JComponent component = (JComponent) components[i];
            setBackground(component, color);
        }
    }        
    
    private void setBackground(JComponent component, Color color) {
        if (component instanceof JLabel || component instanceof JPanel ||
            component instanceof JCheckBox || component instanceof JTabbedPane ||
            component instanceof JRootPane || component instanceof JLayeredPane) {
            
            component.setBackground(color);
            
            Component[] components = component.getComponents();
            for (int i = 0; i < components.length; i++) {
                JComponent subComponent = (JComponent) components[i];
                setBackground(subComponent, color);
            }
        }
    }    
    
    private class HelpAction implements Action {
        public boolean isEnabled() {
            return true;
        }

        public void setEnabled(boolean arg0) {}
        public void actionPerformed(ActionEvent arg0) {
            if (helpIndex != null) {
                JavaHelp.setHelpIndex(helpIndex);
            }
            new JavaHelp();
        }
        
        public void putValue(String arg0, Object arg1) {}
        public void addPropertyChangeListener(PropertyChangeListener arg0) {}
    
        public Object getValue(String arg0) {
            return null;
        }
        
        public void removePropertyChangeListener(PropertyChangeListener arg0) {}
    }      
    
}
