/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.dialogs;

import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.Image;
import java.awt.Insets;

import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;
import javax.swing.JTextArea;
import javax.swing.ScrollPaneConstants;
import javax.swing.border.BevelBorder;

import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.console.components.DCFrame;
import net.sf.dc.console.components.Layout;
import net.sf.dc.core.IconLibrary;
import net.sf.dc.resources.DCLabels;
import net.sf.dc.resources.DCMessages;
import net.sf.ext.util.Resources;
import net.sf.ext.util.Utilities;

/**
 * @author Robert Jan van der Waals
 * @since 1.4
 * @version 1.50
 */
public class AboutDialog extends DCFrame {
    
    private JButton buttonClose;

    /**
     * Initializes and creates this dialog, then it is shown
     */
    public AboutDialog() {
        buildDialog();
        
        setTitle(Resources.getText(DCLabels.lblAbout));
        setSize(new Dimension(500,450));
        Image img =IconLibrary._icoMain.getImage();
        setIconImage(img);
        img.flush();
        
        Dimension location = Utilities.getCenteredWindowLocation(getSize());
        setLocation(location.width, location.height);
    }

    /**
     * Closes and disposes this dialog
     */
    public void close() {
        this.dispose();
    }

    /**
     * Created this dialog
     */
    private void buildDialog() {
        JTabbedPane tabbedPane = ComponentFactory.getTabbedPane();
        
        //**********************************************************
        //About panel
        //**********************************************************
        JPanel panelAbout = new JPanel(false);
        panelAbout.setLayout(Layout.getGBL());
        
        JTextArea textAbout = ComponentFactory.getTextArea();
        textAbout.setBackground(ComponentFactory.getTableColor());

        JScrollPane scrollAbout = new JScrollPane(textAbout);
        scrollAbout.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
        scrollAbout.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_NEVER);
        
        textAbout.setText("Data Crow was founded by Robert Jan van der Waals \n\r" +
                          "Original product: CD Library 3.03 \r\n" +
                          "\r\n" +
                          "Data Crow uses the HSQL database engine" +
                          "\r\n" +
                          "The product is free for use and the source can be downloaded, " +
                          "edited and distributed under the GPL license terms \r\n" +
                          "\r\n" +
                          "Developers: \r\n" +
                          "Robert Jan van der Waals (rwaals@users.sourceforge.net) \r\n" +
                          "Jesper Kusk Christensen \r\n" +
                          "\r\n" +
                          "Contact: \r\n" +
                          "info@datacrow.net \r\n" + 
                          "http://www.datacrow.net \r\n" +
                          "http://sourceforge.net/projects/datacrow");
        textAbout.setEditable(false);
        scrollAbout.setBorder(new BevelBorder(10));
        panelAbout.add(scrollAbout, Layout.getGBC(0, 0, 1, 1, 1.0, 1.0,
                               GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                               new Insets(5, 5, 5, 5), 0, 0));

        //**********************************************************
        //Credits
        //**********************************************************        
        JPanel panelCredits = new JPanel(false);
        panelAbout.setLayout(Layout.getGBL());
        
        JTextArea textCredits = ComponentFactory.getTextArea();
        textAbout.setBackground(ComponentFactory.getTableColor());

        JScrollPane scrollCredits = new JScrollPane(textCredits);
        scrollCredits.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
        scrollCredits.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_NEVER);
        
        textCredits.setText(
                "* http://www.freedb.org for allowing me to retrieve data from their webservers \r\n" + 
                "* Amazon.com for allowing me to retrieve data from their webservers \r\n " +
                "  http://www.amazon.com \r\n " +
                "* Imdb.com for allowing me to extract data from their database \r\n " + 
                "  http://www.imdb.com \r\n " +
                "* JD3Lib to help me with Mp3 ID3/ID3v2 tags reading \r\n " + 
                "  http://sourceforge.net/projects/jd3lib \r\n " +
                "  Delivered as JD3Lib-a4.jar \r\n " +
                "* Entagged. I have been switching back and forth between several music tag \r\n " + 
                "  readers. Now there entagged and I like it so far.. \r\n " +
                "  http://entagged.sourceforge.net/ \r\n " +
                "* HSQL: This product includes Hypersonic SQL. \r\n " +
                "  Originally developed by Thomas Mueller and the Hypersonic SQL Group. \r\n " + 
                "  I want to thank Thomas Mueller for providing this application with an easy \r\n " +
                "  to use, powerfull but small and platform independent database. \r\n " +
                "  http://hsqldb.sourceforge.net/ \r\n " +
                "* iText for providing me with the PDF and the HTML reporting \r\n " +
                "  http://www.lowagie.com/iText/ \r\n " +
                "* Tonic Look and Feel \r\n " +
                "  Delivered as toniclf.jar \r\n " +
                "  http://www.digitprop.com/p.php?page=java&lang=eng \r\n " +
                "* izPack \r\n " +
                "  for providing a smooth way to install Data Crow on multiple platforms \r\n " +
				"  http://www.izforge.com/izpack/ \r\n ");
        
        textCredits.setEditable(false);
        scrollCredits.setBorder(new BevelBorder(10));
        
        panelCredits.add(scrollCredits, Layout.getGBC(0, 0, 1, 1, 1.0, 1.0,
                         GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                         new Insets(5, 5, 5, 5), 0, 0));
        
        
        
        //**********************************************************
        //Main panel
        //**********************************************************
        tabbedPane.addTab(Resources.getText(DCLabels.lblAbout), scrollAbout);
        tabbedPane.addTab(Resources.getText(DCLabels.lblCredits), scrollCredits);

        
        getContentPane().setLayout(Layout.getGBL());
        getContentPane().add(tabbedPane,   Layout.getGBC(0, 0, 1, 1, 1.0, 1.0,
                                           GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                                           new Insets(5, 5, 5, 5), 0, 0));

        setTitle(Resources.getText(DCMessages.msgQuestion));
        pack();
    }
}
