/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.dialogs;

import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.console.components.DCDialog;
import net.sf.dc.console.components.Layout;
import net.sf.dc.console.components.ShortTextField;
import net.sf.dc.core.DataCrow;
import net.sf.dc.core.Repository;
import net.sf.dc.resources.DCLabels;
import net.sf.dc.resources.DCMessages;
import net.sf.ext.jflexsett.settings.Settings;
import net.sf.ext.util.Resources;
import net.sf.ext.util.Utilities;

/**
 * Login shows a small login window. The user needs to fill the database name
 *
 * @author Robert Jan van der Waals
 * @since 1.3
 * @version 1.6
 */
public class LoginDialog extends DCDialog {

    public static boolean done = false;

    private JLabel labelDriver;
    private JTextField textDriver;
    private JLabel labelDatabaseName;
    private ShortTextField textDatabaseName;

    private JButton buttonOK;
    private JButton buttonCancel;

    private JPanel panelInput = new JPanel(false);
    private JPanel panelActions = new JPanel(false);

    /**
     * Initializes and creates this dialog, then it is shown
     */
    public LoginDialog() {
        super();
        done = false;
        buildDialog();
        setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
        this.setTitle(Resources.getText(DCLabels.lblConnection));
        
        setHelpIndex("dc.Window.Starting");

    	addWindowListener(new WindowAdapter() {
                public void windowClosing(WindowEvent e) {
                	System.exit(0);
                }
    	});

        this.setSize(new Dimension(350,150));
        
        Dimension location = Utilities.getCenteredWindowLocation(getSize());
        setLocation(location.width, location.height);
        
        setBackground(Settings.getValueAsColor(Repository.settings.stColor));
    }
    
    public void setVisible(boolean b) {
        super.setVisible(b);
        
        if (b) {
            //DataCrow.moveSplashScreenToBack();
            requestFocus(true);
            requestFocusInWindow(true);
            toFront();
            buttonOK.requestFocus(true);
        }
    }
    
    /**
     * Closes and disposes this dialog
     */
    public void close() {
        DataCrow.moveSplashScreenToFront();
        this.dispose();
    }

    /**
     * Verifies the selected database String and driver and saves them to the
     * Settings class
     */
    protected void verifyConnection() {
        String s = textDatabaseName.getText().trim();
        if (!s.equals("")) {
            Settings.setValue(Repository.settings.stConnectionString,
                              textDatabaseName.getText().trim());
        }

        done = true;
        close();
    }

    /**
     * Created this dialog
     */
    private void buildDialog() {
        //**********************************************************
        //Input panel
        //**********************************************************
        panelInput.setLayout(Layout.getGBL());

        labelDatabaseName = ComponentFactory.getLabel(Resources.getText(DCLabels.lblDatabaseName));
        textDatabaseName = ComponentFactory.getShortTextField(20);
        
        textDatabaseName.setText(Settings.getValueAsString(Repository.settings.stConnectionString));

        panelInput.add(labelDatabaseName,   Layout.getGBC(0, 1, 1, 1, 1.0, 1.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                            new Insets(5, 5, 5, 5), 0, 0));
        panelInput.add(textDatabaseName,    Layout.getGBC(1, 1, 1, 1, 1.0, 1.0,
                                            GridBagConstraints.NORTHEAST, GridBagConstraints.HORIZONTAL,
                                            new Insets(5, 5, 5, 5), 0, 0));

        //**********************************************************
        //Actions panel
        //**********************************************************        
        panelActions.setLayout(Layout.getGBL());
        
        buttonOK = ComponentFactory.getButton(Resources.getText(DCLabels.lblOK));
        buttonCancel = ComponentFactory.getButton(Resources.getText(DCLabels.lblCancel));
        buttonOK.addActionListener(new YesButtonAction());
        buttonCancel.addActionListener(new CancelButtonAction());

        panelActions.add(buttonOK,      Layout.getGBC(0, 0, 1, 1, 0.0, 0.0,
                                        GridBagConstraints.WEST, GridBagConstraints.NONE,
                                        new Insets(5, 5, 5, 5), 0, 0));
        panelActions.add(buttonCancel,  Layout.getGBC(1, 0, 1, 1, 0.0, 0.0,
                                        GridBagConstraints.WEST, GridBagConstraints.NONE,
                                        new Insets(5, 5, 5, 5), 0, 0));

        //**********************************************************
        //Main panel
        //**********************************************************        
        getContentPane().setLayout(Layout.getGBL());

        getContentPane().add(panelInput,   Layout.getGBC(0, 0, 1, 1, 1.0, 1.0,
                                           GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                                           new Insets(5, 5, 5, 5), 0, 0));
        getContentPane().add(panelActions, Layout.getGBC(0, 1, 1, 1, 1.0, 1.0,
                                           GridBagConstraints.SOUTHWEST, GridBagConstraints.NONE,
                                           new Insets(5, 5, 5, 5), 0, 0));

        setTitle(Resources.getText(DCMessages.msgQuestion));
        setResizable(true);
        pack();
    }


    private class YesButtonAction implements ActionListener {
        public void actionPerformed(ActionEvent e) {
            verifyConnection();
        }
    }

    private class CancelButtonAction implements ActionListener {
        public void actionPerformed(ActionEvent e) {
            System.exit(0);
        }
    }
}
