/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.musicfile.organizer;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.Insets;

import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.console.components.Layout;
import net.sf.dc.core.Repository;
import net.sf.dc.resources.DCLabels;
import net.sf.ext.jflexsett.settings.Settings;
import net.sf.ext.util.Resources;

/**
 * @author Robert Jan van der Waals
 * @since 1.4
 * @version 1.5
 */
public abstract class MusicFileOrganizerBasePanel extends JPanel {
    
    protected final Color color = 
        Settings.getValueAsColor(Repository.settings.stColor);
    
    private final JTextArea textLog = ComponentFactory.getTextArea();
    private final JProgressBar progress = new JProgressBar();
    protected MusicFileOrganizerDialog ui;

    public void updateProgressBar(int value) {
        progress.setValue(value);
    }
    
    /**
     * Writes a message to the top of the log field
     * @param text  event Strings
     */
    public void updateLog(String text) {
        textLog.setText(text + '\n' + textLog.getText());
    }    

    /**
     * Initializes the progressbar
     * @param maximum maximum value
     */
    public void initProgressBar(int maximum) {
        progress.setMinimum(0);
        progress.setMaximum(maximum);
        progress.setValue(0);
    }
    
    public void finish() {
        if (ui != null) {
        	ui.allowAction(true);
        }
        progress.setValue(0);
    }
    
    protected abstract void cancel();
    
    protected abstract void start(MusicFileOrganizerDialog ui);
    
    protected JPanel createProgressPanel() {
        JPanel progressPanel = new JPanel(false); 
        progressPanel.setBackground(color);
        progressPanel.setLayout(Layout.getGBL());
        progressPanel.add(progress, Layout.getGBC( 0, 0, 1, 1, 1.0, 1.0
                         ,GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL,
                          new Insets(5, 5, 5, 5), 0, 0));
        return progressPanel;
    }

    /**
     * Creates the logging panel
     */
    protected JPanel createLogPanel() {
        JPanel logPanel = new JPanel(false);
        logPanel.setBackground(color);
        
        JScrollPane scroll = new JScrollPane(textLog);
        scroll.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
        scroll.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED);
        scroll.setPreferredSize(new Dimension(550, 300));
        textLog.setEditable(false);

        logPanel.setLayout(Layout.getGBL());
        logPanel.add(scroll, Layout.getGBC( 0, 0, 7, 1, 1.0, 1.0
                    ,GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                     new Insets(0, 0, 0, 0), 0, 0));
        
        logPanel.setBorder(ComponentFactory.getTitleBorder(
                           Resources.getText(DCLabels.lblLogEvent)));
        return logPanel;
    }
}
