/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.musicfile.organizer;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.Image;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;

import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.console.components.DCFrame;
import net.sf.dc.console.components.Layout;
import net.sf.dc.core.IconLibrary;
import net.sf.dc.core.Repository;
import net.sf.dc.processes.MusicFilesOrganizerTask;
import net.sf.dc.resources.DCLabels;
import net.sf.ext.jflexsett.settings.Settings;
import net.sf.ext.util.Resources;
import net.sf.ext.util.Utilities;

/**
 * @author Robert Jan van der Waals
 * @since 1.4
 * @version 1.5
 */
public class MusicFileOrganizerDialog extends DCFrame {

    private final Color color = 
        Settings.getValueAsColor(Repository.settings.stColor);

    private JTabbedPane tabbedPane = ComponentFactory.getTabbedPane();
    
    private JButton buttonCancel = ComponentFactory.getButton(
            Resources.getText(DCLabels.lblCancel));
    private JButton buttonStart = ComponentFactory.getButton(
            Resources.getText(DCLabels.lblStart));
    private JButton buttonClose = ComponentFactory.getButton(
            Resources.getText(DCLabels.lblClose));

    
    private MusicFilesOrganizerTask thread;

    /**
     * Builds and initializes the UI
     */
    public MusicFileOrganizerDialog() {
        buildDialog();
        
        setHelpIndex("dc.Tools.MusicOrganizer");
        
        buttonStart.setEnabled(true);
        buttonCancel.setEnabled(false);
        
        setTitle(Resources.getText(DCLabels.lblMusicFileOrganizer));
        
        addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                Settings.setValue(Repository.settings.stMusicOrganizerViewSize,
                                  getSize());
                //cancel();
            }
        });

        Image image = IconLibrary._icoMp3Organizer.getImage();
        this.setIconImage(image);
        image.flush();
        
        this.setSize(Settings.getValueAsDimension(
                Repository.settings.stMusicOrganizerViewSize));
                
        Dimension location = Utilities.getCenteredWindowLocation(getSize());
        setLocation(location.width, location.height);
    }
    
    public void allowAction(boolean b) {
    	buttonStart.setEnabled(b);
        buttonCancel.setEnabled(!b);
    }
    
    private void start() {
        allowAction(false);
        MusicFileOrganizerBasePanel panel = getActivePanel();
        panel.start(this);
    }
    
    private void cancel() {
        MusicFileOrganizerBasePanel panel = getActivePanel();
        allowAction(true);
        panel.cancel();
    }
    
    private void close() {
        cancel();
        setVisible(false);
    }
    
    private MusicFileOrganizerBasePanel getActivePanel() {
        int index = tabbedPane.getSelectedIndex();
        MusicFileOrganizerBasePanel panel =
            (MusicFileOrganizerBasePanel) tabbedPane.getComponent(index);
        return panel;
    }

    private void buildDialog() {
    	MusicFileMoverPanel moverPanel = new MusicFileMoverPanel();
        MusicFileRenamerPanel renamerPanel = new MusicFileRenamerPanel(this);

        getContentPane().setLayout(Layout.getGBL());
        getContentPane().setBackground(color);
        
        
        tabbedPane.addTab("Move files", IconLibrary._icoCategory, moverPanel);
        
        getContentPane().add(tabbedPane,          Layout.getGBC( 0, 0, 1, 1, 20.0, 20.0
                            ,GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                             new Insets(5, 5, 5, 5), 0, 0));
        getContentPane().add(createActionPanel(), Layout.getGBC( 0, 1, 1, 1, 1.0, 1.0
                            ,GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                             new Insets(5, 5, 5, 5), 0, 0));
        
        this.setResizable(true);
        pack();
    }
    
    protected JPanel createActionPanel() {
        JPanel actionPanel = new JPanel(false);
        actionPanel.setBackground(color);
        
        actionPanel.add(buttonStart);
        actionPanel.add(buttonCancel);
        actionPanel.add(buttonClose);
        
        buttonClose.addActionListener(new CloseAction());
        buttonStart.addActionListener(new StartAction());
        buttonCancel.addActionListener(new CancelAction());

        return actionPanel;
    } 
    
    private final class CloseAction implements ActionListener { 
        public void actionPerformed(ActionEvent arg0) {
            close();
        }
    }
    
    private final class StartAction implements ActionListener { 
        public void actionPerformed(ActionEvent arg0) {
            start();
        }
    }
    
    private final class CancelAction implements ActionListener { 
        public void actionPerformed(ActionEvent arg0) {
            cancel();
        }
    }     
}
