/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.software;

import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;

import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.sf.dc.console.InternetSearchForm;
import net.sf.dc.console.ItemForm;
import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.console.components.Layout;
import net.sf.dc.console.dialogs.MessageBox;
import net.sf.dc.core.Repository;
import net.sf.dc.core.objects.DCObject;
import net.sf.dc.core.objects.software.Software;
import net.sf.dc.processes.http.AmazonSoftwareUpdate;
import net.sf.dc.resources.DCLabels;
import net.sf.dc.resources.DCMessages;
import net.sf.ext.jflexsett.settings.Settings;
import net.sf.ext.util.Resources;
import net.sf.ext.util.Utilities;

/**
 * Searches Amazon.com for information about programs and games
 *
 * @author Robert-Jan van der Waals
 * @since 1.3
 * @version 0.75
 */
public class AmazonSoftwareSearchForm extends InternetSearchForm {
    
    protected JTextField textSearch;
    protected JButton buttonSearch;
    
    public AmazonSoftwareSearchForm(DCObject dco, ItemForm itemForm) {
        super(dco, itemForm);
        setTitle(Resources.getText(DCLabels.lblAmazonUpdateProcess));
    }
    
    public AmazonSoftwareSearchForm(DCObject dco, int tab) {
        super(dco, tab);
        setTitle(Resources.getText(DCLabels.lblAmazonUpdateProcess));
    }
    
    public void setDefaultValues() {
        setSize(Settings.getValueAsDimension(
                Repository.settings.stAmazonSearchFormViewSize));        
        
        if (dco != null) {
        	textSearch.setText(dco.getValue(Software._A_NAME).toString());
        }
        
        Dimension dim = Utilities.getCenteredWindowLocation(getSize());
        setLocation(dim.width, dim.height);
    }

    public void setCancelMode() {
        cancelled = false;
        buttonSearch.setEnabled(false);
        buttonStopSearch.setEnabled(true);
    }    
    
    public void setSearchMode() {
        buttonSearch.setEnabled(true);
        buttonStopSearch.setEnabled(false);        
    }
    
    public void saveSettings() {
        super.saveSettings();
        Settings.setValue(Repository.settings.stAmazonSearchFormViewSize,
                          getSize());
    }    
    
    public void startSearch() {
        setCancelMode();
        saveSettings();
        
        String keywords = textSearch.getText();
        if (!keywords.equals("")) {
        	process = new AmazonSoftwareUpdate(this, textSearch.getText(), 
                                               checkBroadband.isSelected());
        	process.setPriority(Thread.MAX_PRIORITY);
        	process.start();
        } else {
            setSearchMode();
        	new MessageBox(this,
                           Resources.getText(DCMessages.msgAmazonNeedsTitle),
                           MessageBox._WARNING);
        }
    }
    
    public JPanel getSearchPanel() {
        JPanel panel = new JPanel(false);
        panel.setLayout(Layout.getGBL());
        panel.setBackground(color);
        
        textSearch = ComponentFactory.getTextField();
        buttonSearch =  ComponentFactory.getButton(Resources.getText(DCLabels.lblFind));
        buttonSearch.addActionListener(new SearchAction());
        buttonSearch.setMnemonic(KeyEvent.VK_F);
        
        panel.setLayout(Layout.getGBL());                                
        panel.add(textSearch,   Layout.getGBC( 0, 0, 1, 1, 90.0, 90.0
                                     ,GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL,
                                      new Insets(5, 5, 5, 5), 0, 0));                         
        panel.add(buttonSearch, Layout.getGBC( 1, 0, 1, 1, 1.0, 1.0
                                     ,GridBagConstraints.EAST, GridBagConstraints.HORIZONTAL,
                                      new Insets(5, 5, 5, 5), 0, 0));
        return panel;
    }
    
    private class SearchAction implements ActionListener{
        public void actionPerformed(ActionEvent e) {
            startSearch();   
        }
    }    
}
