/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 The Data Crow team                          *
 *                              info@datacrow.net                             *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.wf.requests;

import java.util.Collection;

import net.sf.dc.console.MainFrame;
import net.sf.dc.core.modules.DCModule;
import net.sf.dc.core.modules.DCModules;

/**
 * Request for removing rows from the table
 * 
 * @author Robert Jan van der Waals
 * @version 1.6
 * @since 1.4
 */
public class RemoveRowsRequest implements IRequest {

    private final String[] ids;
    private final int module;
    private final int panel;
    private boolean executeOnFail = false;
    
    public RemoveRowsRequest(int module, int panel, String[] ids) {
        this.ids = ids;
        this.module = module;
        this.panel = panel;
    }
    
    public void execute(Collection data) {
        DCModule mod = DCModules.getModule(module);

        try {
        	if (panel == MainFrame._SEARCHTAB) {
        		mod.getSearchPanel().removeRows(ids);
        	} else {
        		mod.getInsertPanel().removeRows(ids);
        	}
        } catch (Exception ignore) {}
    }
    
    public boolean getExecuteOnFail() {
        return executeOnFail;
    }
    
    public void setExecuteOnFail(boolean b) {
        executeOnFail = b;
    }
}
